# For Haskell Packaging Guidelines see:
# - https://fedoraproject.org/wiki/Packaging:Haskell
# - https://fedoraproject.org/wiki/PackagingDrafts/Haskell

%global pkg_name tar

%global common_summary Reading, writing and manipulating tar archive files

%global common_description This library is for working with ".tar" archive files. It \
can read and write a range of common variations of archive \
format including V7, USTAR, POSIX and GNU formats. It \
provides support for packing and unpacking portable archives. \
This makes it suitable for distribution but not backup \
because details like file ownership and exact permissions are \
not preserved.

Name:           ghc-%{pkg_name}
Version:        0.3.1.0
Release:        13%{?dist}
Summary:        %{common_summary}

Group:          System Environment/Libraries
License:        BSD
# BEGIN: cabal2spec-0.24
URL:            http://hackage.haskell.org/package/%{pkg_name}
Source0:        http://hackage.haskell.org/packages/archive/%{pkg_name}/%{version}/%{pkg_name}-%{version}.tar.gz
ExclusiveArch:  %{ghc_arches}
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  hscolour
# END: cabal2spec-0.24

BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-old-time-devel

%description
%{common_description}


%package -n ghc-%{pkg_name}-devel
Summary:        Development files for %{common_summary}
Group:          Development/Libraries
# BEGIN: cabal2spec-0.24
%{?ghc_devel_requires}
Obsoletes:      ghc-%{pkg_name}-prof < %{version}-%{release}
Provides:       ghc-%{pkg_name}-prof = %{version}-%{release}
# END: cabal2spec-0.24

%description -n ghc-%{pkg_name}-devel
%{common_description}

This package contains the development files.


%prep
%setup -q -n %{pkg_name}-%{version}


%build
%ghc_lib_build


%install
%ghc_lib_install


%post -n ghc-%{pkg_name}-devel
%ghc_pkg_recache

%postun -n ghc-%{pkg_name}-devel
%ghc_pkg_recache


%if %{undefined ghc_without_shared}
%files -n ghc-%{pkg_name} -f ghc-%{pkg_name}.files
%defattr(-,root,root,-)
%endif

%files -n ghc-%{pkg_name}-devel -f ghc-%{pkg_name}-devel.files
%defattr(-,root,root,-)


%changelog
* Sat Jul 09 2011 Ben Boeckel <mathstuf@gmail.com> - 0.3.1.0-13
- Update to cabal2spec-0.24

* Thu Jun 23 2011 Jens Petersen <petersen@redhat.com> - 0.3.1.0-12
- BR ghc-Cabal-devel instead of ghc-prof and use ghc_arches (cabal2spec-0.23.2)

* Thu Mar 10 2011 Fabio M. Di Nitto <fdinitto@redhat.com> - 0.3.1.0-11
- Enable build on sparcv9

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.1.0-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Jan 15 2011 Ben Boeckel <mathstuf@gmail.com> - 0.3.1.0-9
- Update to cabal2spec-0.22.4
- Rebuild

* Thu Nov 25 2010 Jens Petersen <petersen@redhat.com> - 0.3.1.0-8
- update url

* Sun Nov 07 2010 Ben Boeckel <mathstuf@gmail.com> - 0.3.1.0-7
- Rebuild
- Update summary and description

* Sat Sep  4 2010 Jens Petersen <petersen@redhat.com> - 0.3.1.0-6
- add hscolour and doc obsolete (cabal2spec-0.22.2)

* Sun Jun 27 2010 Jens Petersen <petersen@redhat.com> - 0.3.1.0-5
- sync cabal2spec-0.22.1

* Tue Apr 27 2010 Jens Petersen <petersen@redhat.com> - 0.3.1.0-4
- rebuild against ghc-6.12.2
- condition ghc_lib_package

* Mon Jan 11 2010 Jens Petersen <petersen@redhat.com> - 0.3.1.0-3
- update to ghc-rpm-macros-0.5.1 and cabal2spec-0.21.1:
- drop doc and prof bcond
- use ghc_lib_package

* Sat Dec 26 2009 Jens Petersen <petersen@redhat.com> - 0.3.1.0-2
- update for ghc-6.12.1: add shared library support
- use new ghc*_requires macros: needs ghc-rpm-macros 0.4.0
- add common_summary and common_description

* Fri Aug 28 2009 Yaakov M. Nemoy <ynemoy@fedoraproject.org> - 0.3.1.0-1
- updated to latest upstream

* Sun Aug 23 2009 Yaakov M. Nemoy <loupgaroublond@gmail.com> - 0.3.0.0-2
- updated to latest cabal2spec output

* Tue Mar  3 2009 Yaakov M. Nemoy <loupgaroublond@gmail.com> - 0.3.0.0-1
- initial packaging for Fedora created by cabal2spec
